@@ -824,6 +824,9 @@ meta_monitor_config_get_stored (MetaMonitorConfig *self,
   MetaConfiguration key;
   MetaConfiguration *stored;
 
+  if (n_outputs == 0)
+    return NULL;
+
   make_config_key (&key, outputs, n_outputs, -1);
   stored = g_hash_table_lookup (self->configs, &key);
 
@@ -1231,6 +1234,12 @@ meta_monitor_config_make_default (MetaMonitorConfig  *self,
   outputs = meta_monitor_manager_get_outputs (manager, &n_outputs);
   meta_monitor_manager_get_screen_limits (manager, &max_width, &max_height);
 
+  if (n_outputs == 0)
+    {
+      meta_verbose ("No output connected, not applying configuration\n");
+      return;
+    }
+
   default_config = make_default_config (self, outputs, n_outputs, max_width, max_height);
 
   if (default_config != NULL)
